#
# spec file for package gawk (Version 3.1.5)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           gawk
BuildRequires:  libpng tetex
Url:            http://www.gnu.org/software/gawk/
License:        GPL v2 or later
Group:          Productivity/Text/Utilities
Provides:       awk
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Version:        3.1.5
Release:        18.8.39
Summary:        GNU awk
Source:         gawk-%{version}.tar.bz2
Patch:          gawk-%{version}.diff
Patch1:         iop-malloced.diff
Patch2:         fieldwidths.diff
Patch3:         embedded-nul.diff
Patch4:         parallel-make.diff
Patch5:         dfa-mbcset.diff
Patch6:         wconcat.diff
Patch7:         wconcat2.diff
Patch8:         sub-common.diff
Patch9:         gawk-3.1.5-double-free.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNU awk is upwardly compatible with the System V Release 4 awk.  It is
almost completely POSIX 1003.2 compliant.



Authors:
--------
    David Trueman <david@cs.dal.ca>
    Arnold Robbins <arnold@skeeve.com>
    Michal Jaegermann <michal@gorte.phys.ualberta.ca>
    Scott Deifik <scottd@amgen.com>
    Darrel Hankerson <hankedr@mail.auburn.edu>
    Kai Uwe Rommel <rommel@ars.de>
    Pat Rankin <rankin@eql.caltech.edu>

%package doc
License:        GPL v2 or later
Summary:        GAWK Package Documentation.
Group:          Productivity/Text/Utilities
AutoReqProv:    on
Provides:       gawkdoc
Obsoletes:      gawkdoc

%description doc
Documentation for gawk.



Authors:
--------
    David Trueman <david@cs.dal.ca>
    Arnold Robbins <arnold@skeeve.com>
    Michal Jaegermann <michal@gorte.phys.ualberta.ca>
    Scott Deifik <scottd@amgen.com>
    Darrel Hankerson <hankedr@mail.auburn.edu>
    Kai Uwe Rommel <rommel@ars.de>
    Pat Rankin <rankin@eql.caltech.edu>

%prep
%setup -q
%patch
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6 -p1
%patch7
%patch8
%patch9 -p1 
rm -f regex.[ch]

%build
%{suse_update_config -f}
rm -f acinclude.m4
autoreconf --force --install
export CFLAGS=$RPM_OPT_FLAGS
./configure --prefix=/usr --libexecdir=%{_libdir} \
	    --mandir=%{_mandir} --infodir=%{_infodir}
%if %do_profiling
  make %{?jobs:-j%jobs} CFLAGS="$CFLAGS %cflags_profile_generate"
  make check
  make clean
  make %{?jobs:-j%jobs} CFLAGS="$CFLAGS %cflags_profile_feedback"
%else
  make %{?jobs:-j%jobs}
%endif
make check
cd doc
make dvi
make postscript
make awkcard.ps
gzip *.ps

%install
make install DESTDIR=$RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT/bin
mv -f $RPM_BUILD_ROOT/usr/bin/awk $RPM_BUILD_ROOT/usr/bin/gawk \
      $RPM_BUILD_ROOT/bin
ln -sf ../../bin/awk ../../bin/gawk $RPM_BUILD_ROOT/usr/bin
ln -sf gawk.1 $RPM_BUILD_ROOT%{_mandir}/man1/awk.1
rm -f $RPM_BUILD_ROOT/usr/bin/*-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post
%install_info --info-dir=%{_infodir} %{_infodir}/gawk.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/gawkinet.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gawk.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gawkinet.info.gz

%files
%defattr(-,root,root)
%doc AUTHORS COPYING FUTURES LIMITATIONS NEWS POSIX.STD PROBLEMS
%doc README README_d
/bin/awk
/bin/gawk
/usr/bin/awk
/usr/bin/gawk
/usr/bin/igawk
/usr/bin/pgawk
%dir %{_libdir}/awk
%{_libdir}/awk/grcat
%{_libdir}/awk/pwcat
%dir /usr/share/awk
/usr/share/awk/*.awk
/usr/share/locale/*/LC_MESSAGES/*.mo
%doc %{_infodir}/*.info.gz
%doc %{_mandir}/man1/*.1.gz

%files doc
%defattr(-,root,root)
%doc doc/awkcard.ps.gz
%doc doc/gawk.dvi
%doc doc/gawk.ps.gz
%doc doc/gawk.1.ps.gz
%doc doc/igawk.1.ps.gz

%changelog
* Tue Apr 21 2009 sf@suse.de
- added gawk-3.1.5-double-free.diff
  (bnc # 218161)
* Sun Mar  5 2006 schwab@suse.de
- Add two wide string bug fixes.
* Thu Feb  9 2006 schwab@suse.de
- Fix dfa generation of interval expressions [#148453].
* Thu Jan 26 2006 schwab@suse.de
- Use %%jobs.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  1 2005 schwab@suse.de
- Fix length on strings with embedded NUL.
* Fri Oct  7 2005 schwab@suse.de
- Fix off-by-one when processing FIELDWIDTHS.
* Fri Sep  2 2005 schwab@suse.de
- Update to gaw 3.1.5.
* Wed May 25 2005 schwab@suse.de
- Update flonum parsing patch.
* Sat Feb 12 2005 schwab@suse.de
- Add libpng to neededforbuild.
* Wed Feb  2 2005 schwab@suse.de
- Ignore exit code from pipes.
* Tue Sep 28 2004 schwab@suse.de
- Fix parsing of floating point number that start with more than one
  zero.
* Sun Sep 19 2004 schwab@suse.de
- Disable invalid shortcut in dfaexec [#44512].
- Fix reading past EOF.
* Mon Aug 23 2004 schwab@suse.de
- Update to gawk 3.1.4.
* Fri Aug  6 2004 schwab@suse.de
- Use random from glibc [#43568].
* Thu Aug  5 2004 schwab@suse.de
- Update to gawk 3.1.3l.
* Thu Jul 22 2004 schwab@suse.de
- Fix int/long mismatch.
* Mon Apr  5 2004 schwab@suse.de
- Disable non-POSIX strtod replacement [#38332].
* Fri Mar 12 2004 schwab@suse.de
- Fix doc bug.
* Sat Jan 10 2004 adrian@suse.de
- do not strip during install, let rpm do it
* Wed Jul  9 2003 schwab@suse.de
- Update to gawk 3.1.3.
* Thu Jun  5 2003 jh@suse.de
- Enable profile feedback
* Tue May 13 2003 schwab@suse.de
- Add %%defattr.
- Fix file list.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar 27 2003 schwab@suse.de
- Update to gawk 3.1.2.
* Fri Feb  7 2003 schwab@suse.de
- Fix spec file.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Mon Nov 18 2002 schwab@suse.de
- Add AM_GNU_GETTEXT_VERSION.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug  5 2002 schwab@suse.de
- Add fix for gsub.
* Mon Jul 29 2002 schwab@suse.de
- Fix broken patch.
* Thu Jul 18 2002 schwab@suse.de
- Add lint check for delete.
* Tue May 14 2002 schwab@suse.de
- Add fix for memory leak in loops.
- Add fix for side effects in split().
* Fri May 10 2002 schwab@suse.de
- Update to gawk-3.1.1 (bugfix release).
* Tue Apr  9 2002 schwab@suse.de
- Fix default AWKPATH.
* Sun Mar 31 2002 schwab@suse.de
- Fix for new gettext.
* Sun Mar 17 2002 schwab@suse.de
- Fix buffer overflow.
* Mon Feb 18 2002 schwab@suse.de
- Workaround spurious limitation in regex matcher.
- Fix bogus assertion in strtonum.
* Mon Jan 28 2002 schwab@suse.de
- Add i18n patch.
* Fri Jan 11 2002 schwab@suse.de
- Two more patches from the author:
  * Fix use of getgroups
  * Fix grammer in for statement.
* Fri Nov 30 2001 schwab@suse.de
- Replace overrun patch with a better one.
- Fix provides.
* Mon Nov 26 2001 schwab@suse.de
- Use regex from libc again.
* Wed Nov  7 2001 schwab@suse.de
- Fix memory overrun.
* Tue Nov  6 2001 schwab@suse.de
- Fix lint checking and off-by-one error for printf.
* Fri Oct  5 2001 schwab@suse.de
- Fix for memory corruption bug from author.
* Tue Sep 25 2001 schwab@suse.de
- Don't set close-on-exec on standard fd (from author).
* Thu Aug 23 2001 schwab@suse.de
- Fix for unary minus operator from author.
* Wed Aug  8 2001 schwab@suse.de
- Fix for memory leak from author.
* Wed Jul 25 2001 schwab@suse.de
- Fix for empty RS and and blank input from author.
* Mon Jul 16 2001 schwab@suse.de
- Fix for index(foo, "") from author.
* Wed Jun 13 2001 schwab@suse.de
- Include fix for allocation bug from author.
* Mon Jun  4 2001 schwab@suse.de
- Update to 3.1.0.
* Sun May 13 2001 schwab@suse.de
- Use included regex.c (#7953).
* Wed May  9 2001 cstein@suse.de
- repacked sources with bzip2.
* Thu Apr 12 2001 schwab@suse.de
- Add patch for \<\> from author.
* Tue Mar 20 2001 schwab@suse.de
- Add parser patch from author.
* Thu Mar  8 2001 schwab@suse.de
- Add two patches from author.
* Tue Oct 24 2000 schwab@suse.de
- Rename subpackage gawkdoc to gawk-doc.
* Thu Sep 14 2000 schwab@suse.de
- Add FIELDWIDTHS bug fix from arnold@skeeve.com.
* Tue Aug  8 2000 schwab@suse.de
- Update to 3.0.6.
* Fri Jun 30 2000 schwab@suse.de
- Fix handling of array indexes.
* Tue Jun 27 2000 schwab@suse.de
- Update to 3.0.5.
* Tue May  9 2000 schwab@suse.de
- Fix symlinks.
* Mon May  8 2000 schwab@suse.de
- Switch to BuildRoot.
- Move /usr/bin/{,g}awk to /bin.
* Fri Apr  7 2000 bk@suse.de
- added suse autoconf update macro
* Tue Apr  4 2000 schwab@suse.de
- Fix IGNORECASE bug.
* Fri Mar 31 2000 schwab@suse.de
- Include more docs.
* Tue Feb 15 2000 schwab@suse.de
- Fix parser bug.
* Tue Feb 15 2000 schwab@suse.de
- Update config{guess,sub} to latest version.
* Tue Jan 18 2000 schwab@suse.de
- /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 schwab@suse.de
- specfile cleanup
- run "make check"
- use regex from libc
* Mon Jul 19 1999 florian@suse.de
- update to gawk 3.0.4
* Thu Dec 10 1998 florian@suse.de
- egcs miscompiles gawk, use gcc instead
* Fri Jul 17 1998 werner@suse.de
- Use mktemp for igawk
* Wed May 13 1998 ro@suse.de
- used dif from jurix-mirror (date Mar 7 1998)
- some of the patches from gnu.utils.bug are still buggy. applied some new
  patches from the author Aharon Robbins to field.c.
* Mon Mar  2 1998 florian@suse.de
- use a complete new patchkit from various bug-reports
  to gnu.utils.bug
* Wed Feb  4 1998 ro@suse.de
- build gawkdoc from same specfile
* Thu Oct  9 1997 florian@suse.de
- prepare for autobuild
* Fri Jul 18 1997 florian@suse.de
- add bug-fixes from gnu.utils.bug
* Fri Jul 18 1997 florian@suse.de
- add several patches from gnu.utils.bug
- gawk should work with c-news again
* Tue May 20 1997 florian@suse.de
- update to version 3.0.3
* Sun Apr 13 1997 florian@suse.de
- add bug-fixes from gnu.utils.bugs
- do not use /usr/libexec anymore
* Wed Jan 22 1997 florian@suse.de
- update to version 3.0.2
